@@ -38,40 +38,19 @@ void BatchExtractTest::testBatchExtraction_data()
     // This is the number of entries in the archive (+ 1, if the autosubfolder is expected).
     QTest::addColumn<int>("expectedExtractedEntriesCount");
 
-    QTest::newRow("extract the whole simple%archive.tar.gz (bug #365798)")
-            << QFINDTESTDATA("data/simple%archive.tar.gz")
-            << true
-            << 5;
+    QTest::newRow("extract the whole simple%archive.tar.gz (bug #365798)") << QFINDTESTDATA("data/simple%archive.tar.gz") << true << 5;
 
-    QTest::newRow("single-folder, no autosubfolder")
-            << QFINDTESTDATA("../kerfuffle/data/one_toplevel_folder.zip")
-            << false
-            << 9;
+    QTest::newRow("single-folder, no autosubfolder") << QFINDTESTDATA("../kerfuffle/data/one_toplevel_folder.zip") << false << 9;
 
-    QTest::newRow("single-folder, autosubfolder")
-            << QFINDTESTDATA("../kerfuffle/data/one_toplevel_folder.zip")
-            << true
-            << 9;
+    QTest::newRow("single-folder, autosubfolder") << QFINDTESTDATA("../kerfuffle/data/one_toplevel_folder.zip") << true << 9;
 
-    QTest::newRow("non single-folder, no autosubfolder")
-            << QFINDTESTDATA("../kerfuffle/data/simplearchive.tar.gz")
-            << false
-            << 4;
+    QTest::newRow("non single-folder, no autosubfolder") << QFINDTESTDATA("../kerfuffle/data/simplearchive.tar.gz") << false << 4;
 
-    QTest::newRow("non single-folder, autosubfolder")
-            << QFINDTESTDATA("../kerfuffle/data/simplearchive.tar.gz")
-            << true
-            << 5;
+    QTest::newRow("non single-folder, autosubfolder") << QFINDTESTDATA("../kerfuffle/data/simplearchive.tar.gz") << true << 5;
 
-    QTest::newRow("single-file, no autosubfolder")
-            << QFINDTESTDATA("data/test.txt.gz")
-            << false
-            << 1;
+    QTest::newRow("single-file, no autosubfolder") << QFINDTESTDATA("data/test.txt.gz") << false << 1;
 
-    QTest::newRow("single-file, autosubfolder")
-            << QFINDTESTDATA("data/test.txt.gz")
-            << true
-            << 1;
+    QTest::newRow("single-file, autosubfolder") << QFINDTESTDATA("data/test.txt.gz") << true << 1;
 }
 
 void BatchExtractTest::testBatchExtraction()
