@@ -6,7 +6,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef CLIPLUGIN_H
 #define CLIPLUGIN_H
 
@@ -17,7 +16,7 @@ class CliPlugin : public Kerfuffle::CliInterface
     Q_OBJECT
 
 public:
-    explicit CliPlugin(QObject *parent, const QVariantList & args);
+    explicit CliPlugin(QObject *parent, const QVariantList &args);
     ~CliPlugin() override;
 
     void resetParsing() override;
@@ -39,7 +38,7 @@ private:
         ArchiveTypeXz,
         ArchiveTypeTar,
         ArchiveTypeZip,
-        ArchiveTypeRar
+        ArchiveTypeRar,
     } m_archiveType;
 
     enum ParseState {
@@ -47,13 +46,13 @@ private:
         ParseStateHeader,
         ParseStateArchiveInformation,
         ParseStateComment,
-        ParseStateEntryInformation
+        ParseStateEntryInformation,
     } m_parseState;
 
     enum BinaryVariant {
         Undefined = 0,
         P7zip,
-        Upstream7zip
+        Upstream7zip,
     } m_binaryVariant;
 
     void setupCliProperties();
